@@ -12,16 +12,6 @@ void run_dmc_sim(Prms &p,
                  std::map<std::string, std::vector<double>> &rsum, 
                  std::map<std::string, std::vector<double>> &rsim, 
                  std::map<std::string, std::vector<std::vector<double>>> &trials) {
-   
-   // values for delta/CAF
-   if (!p.pDelta.empty()) {
-       p.vDelta = p.pDelta; // take specific values
-       p.vDelta.insert(p.vDelta.begin(), 0);
-       p.vDelta.push_back(100);
-   } else {
-       p.vDelta = linspace(0, 100, p.nDelta + 2);
-   }
-   p.vCAF = linspace(0, 100, p.nCAF + 1);
     
     // equation 4
     std::vector<double> eq4(p.tmax);
@@ -30,7 +20,7 @@ void run_dmc_sim(Prms &p,
     rsim["eq4"] = eq4;
     
     // run comp and incomp simulation 
-    std::vector<std::thread> threads(2);
+    std::vector<std::thread> threads;
     std::vector<std::string> compatibility{"comp", "incomp"};
     std::vector<int> sign{1, -1};
     
@@ -61,12 +51,13 @@ void run_dmc_sim_ci(Prms &p,
 
     std::vector<double> rts;
     std::vector<double> errs;
+    std::vector<double> slows;
     std::vector<double> activation_sum(p.tmax);
     std::vector<std::vector<double>> trl_mat(p.nTrlData, std::vector<double>(p.tmax));  // needed if plotting individual trials
 
     std::vector<double> u_vec(p.tmax);
     for (auto i = 0u; i < u_vec.size(); i++)
-        u_vec[i] = sign * rsim["eq4"][i] * ((p.aaShape - 1) / (i + 1) - 1 / p.tau);
+        u_vec[i] = sign * rsim.at("eq4")[i] * ((p.aaShape - 1) / (i + 1) - 1 / p.tau);
 
     // variable drift rate/starting point?
     std::vector<double> dr(p.nTrl, p.drc);
@@ -76,17 +67,19 @@ void run_dmc_sim_ci(Prms &p,
 
     // run simulation and store rts for correct/incorrect trials
     if (p.fullData) {
-        run_simulation(p, activation_sum, trl_mat, u_vec, sp, dr, rts, errs, sign);
+        run_simulation(p, activation_sum, trl_mat, u_vec, sp, dr, rts, errs, slows, sign);
         trials[comp] = trl_mat;
     } else {
-        run_simulation(p, u_vec, sp, dr, rts, errs, sign);
-    }
+        run_simulation(p, u_vec, sp, dr, rts, errs, slows, sign);
+    } 
     
     m.lock();
     rsim["activation_" + comp] = activation_sum;
     rsim["rts_" + comp]        = rts;
     rsim["errs_" + comp]       = errs;
-    rsum["resSum_" + comp]     = calculate_summary(rts, errs, p.nTrl );
+    rsim["slows_" + comp]      = slows;
+    
+    rsum["resSum_" + comp]     = calculate_summary(rts, errs, slows, p.nTrl );
     rsum["delta_pct_" + comp]  = calculate_percentile(p.vDelta, rts);
     rsum["caf_" + comp]        = calculate_caf(rts, errs, p.nCAF);
     m.unlock();
@@ -118,6 +111,7 @@ void run_simulation(Prms &p,
                     std::vector<double> &dr, 
                     std::vector<double> &rts, 
                     std::vector<double> &errs, 
+                    std::vector<double> &slows, 
                     int sign) {
 
     const uint32_t s = p.setSeed ? 1 : std::time(nullptr);
@@ -126,12 +120,18 @@ void run_simulation(Prms &p,
     boost::random::normal_distribution<double> nd_mean_sd(p.resMean, p.resSD);
 
     double activation_trial = 0;
+    double value; 
     for (auto trl = 0u; trl < p.nTrl; trl++) {
         activation_trial = sp[trl];
         for (auto i = 0u; i < p.tmax; i++) {
-            activation_trial += u_vec[i] + dr[trl] + (p.sigm * snd(rng));
-            if (fabs(activation_trial) > p.bnds) {
-                (activation_trial > p.bnds ? rts : errs).push_back(i + nd_mean_sd(rng) + 1); // zero index
+            activation_trial += (u_vec[i] + dr[trl] + (p.sigm * snd(rng)));
+            if (activation_trial > p.bnds) {
+                value = i + nd_mean_sd(rng) + 1;
+                (value < p.rtMax ? rts : slows).push_back(value);
+                break;
+            } else if (activation_trial < -p.bnds) {
+                value = i + nd_mean_sd(rng) + 1;
+                (value < p.rtMax ? errs : slows).push_back(value);
                 break;
             }
         }
@@ -147,6 +147,7 @@ void run_simulation(Prms &p,
                     std::vector<double> &dr, 
                     std::vector<double> &rts, 
                     std::vector<double> &errs, 
+                    std::vector<double> &slows, 
                     int sign ) {
 
     const uint32_t s = p.setSeed ? 1 : std::time(nullptr);
@@ -156,15 +157,21 @@ void run_simulation(Prms &p,
 
     double activation_trial;
     bool criterion;
+    double value;
     for (auto trl = 0u; trl < p.nTrl; trl++) {
         criterion = false;
         activation_trial = sp[trl];
         for (auto i = 0u; i < activation_sum.size(); i++) {
             activation_trial += u_vec[i] + dr[trl] + (p.sigm * snd(rng));
-            if (!criterion && fabs(activation_trial) > p.bnds) {
-                (activation_trial > p.bnds ? rts : errs).push_back(i + nd_mean_sd(rng) + 1); // zero index
+            if (!criterion && activation_trial > p.bnds) {
+                value = i + nd_mean_sd(rng) + 1;
+                (value < p.rtMax ? rts : slows).push_back(value);
                 criterion = true;
-            }
+            } else if (!criterion && activation_trial < -p.bnds) {
+                value = i + nd_mean_sd(rng) + 1;
+                (value < p.rtMax ? errs : slows).push_back(value);
+                criterion = true;
+            } 
             if (trl < p.nTrlData) trial_matrix[trl][i] = activation_trial;
             activation_sum[i] += activation_trial;
         }
@@ -174,40 +181,48 @@ void run_simulation(Prms &p,
 
 }
 
-std::vector<double> calculate_summary(std::vector<double> &rts, std::vector<double> &errs, unsigned long nTrl) {
+std::vector<double> calculate_summary(
+        std::vector<double> &rts, 
+        std::vector<double> &errs, 
+        std::vector<double> &slows, 
+        unsigned long nTrl) {
 
-    // rtCor, sdRtCor, perErr, rtErr, sdRtErr
-    std::vector<double> res(5);
+    // rtCor, sdRtCor, perErr, rtErr, sdRtErr, perSlow
+    std::vector<double> res(6);
     res[0] = accumulate(rts.begin(), rts.end(), 0.0) / rts.size();
     res[1] = std::sqrt(std::inner_product(rts.begin(), rts.end(), rts.begin(), 0.0) / rts.size() - res[0] * res[0]);
     res[2] = (errs.size() / static_cast<float>(nTrl)) * 100;
     res[3] = accumulate(errs.begin(), errs.end(), 0.0) / errs.size();
     res[4] = std::sqrt(std::inner_product(errs.begin(), errs.end(), errs.begin(), 0.0) / errs.size() - res[3] * res[3]);
+    res[5] = (slows.size() / static_cast<double>(nTrl)) * 100;
 
     return res;
 
 }
 
 std::vector<double> calculate_percentile( std::vector<double> vDelta, std::vector<double> rts ) {
-
-    int nDelta = vDelta.size() - 2;
-    float pct_idx;
-    int pct_idx_int;
-    float pct_idx_dec;
-    std::vector<double> res;
     
-    std::sort(rts.begin(), rts.end());
+    int nDelta = vDelta.size() - 2;                                             
+    std::vector<double> res(nDelta, 0);                                         
+    if (rts.size() != 0) {                                                      
+        
+        std::sort(rts.begin(), rts.end());                                      
+        
+        double pct_idx;                                                         
+        int pct_idx_int;                                                        
+        double pct_idx_dec;                                                     
+        
+        for (int i = 0; i < nDelta; i++) {                                      
+            pct_idx = (vDelta[i+1] / 100.0) * (rts.size() - 1);                   
+            pct_idx_int = int(pct_idx);                                         
+            pct_idx_dec = pct_idx - static_cast<double>(pct_idx_int);           
+            res[i] = rts[pct_idx_int] + ((rts[pct_idx_int + 1] - rts[pct_idx_int]) * pct_idx_dec);
+        }                                                                       
+        
+    }                                                                           
+    
+    return res;           
     
-    for (int i = 1; i <= nDelta; i++) {
-
-        pct_idx     = (vDelta[i] / 100.0) * (rts.size()-1);
-        pct_idx_int = int(pct_idx);
-        pct_idx_dec = pct_idx - pct_idx_int;
-
-        res.push_back(rts[pct_idx_int] + ((rts[pct_idx_int + 1] - rts[pct_idx_int]) * pct_idx_dec));
-
-    }
-    return res;
 }
 
 void calculate_delta( std::map<std::string, std::vector<double> > &rdelta) {
@@ -220,38 +235,29 @@ void calculate_delta( std::map<std::string, std::vector<double> > &rdelta) {
 }
 
 std::vector<double> calculate_caf(std::vector<double> &rts, std::vector<double> &errs, int nCAF) {
-
-    std::vector<std::pair<double, bool>> comb;
-    comb.reserve(rts.size() + errs.size());
-    for (double & rt : rts)   comb.emplace_back(std::make_pair(rt, false));
-    for (double & err : errs) comb.emplace_back(std::make_pair(err, true));
-
-    std::sort(comb.begin(), comb.end());
-    std::vector<int> bins(comb.size());
-    for (auto i = 0u; i < comb.size(); i++) 
-        bins[i] = int(nCAF * (i) / comb.size());
-
-    std::vector<long int> nErr(nCAF, 0);
-    std::vector<long int> nCor(nCAF, 0);
-    for (auto i = 0u; i < bins.size(); i++) 
-        (comb[i].second == 0) ? nCor[bins[i]]++ : nErr[bins[i]]++;
-
-    std::vector<double> res;
-    for (auto i = 0u; i < nCor.size(); i++) 
-        res.push_back(1 - (nErr[i] / float(nCor[i] + nErr[i])));
     
-    return res;
-
-}
-
-std::vector<double> linspace(int start, int end, int n) {
-    double step = (end - start) / double(n-1);
-    std::vector<double> out(n);
-    double val = start;
-    for (int i = 0; i < n; i++) {
-        out[i] = val;
-        val += step;
-    }
-    return out;
+    std::vector<double> res(nCAF, 0);                                           
+    
+    if (rts.size() + errs.size() != 0) {                                                     
+        
+        std::vector<std::pair<double, bool> > comb;                                 
+        comb.reserve(rts.size() + errs.size());                                     
+        
+        for (double &rt : rts) comb.emplace_back(std::make_pair(rt, false));    
+        for (double &err : errs) comb.emplace_back(std::make_pair(err, true));  
+        
+        std::sort(comb.begin(), comb.end());                                    
+        std::vector<int> bins(comb.size());                                     
+        for (auto i = 0u; i < comb.size(); i++) bins[i] = int(nCAF * (i) / comb.size());
+        
+        std::vector<long int> countErr(nCAF, 0);                                
+        std::vector<long int> countCor(nCAF, 0);                                
+        for (auto i = 0u; i < bins.size(); i++) (comb[i].second == 0) ? countCor[bins[i]]++ : countErr[bins[i]]++;
+        for (auto i = 0u; i < countCor.size(); i++) res[i] = 1 - (countErr[i] / float(countCor[i] + countErr[i]));
+        
+    }                                                                           
+    
+    return res;                  
+    
 }
 
