@@ -14,7 +14,7 @@ void run_dmc_sim_ci(Prms &p,
                     std::map<std::string, std::vector<std::vector<double>>> &trials, 
                     std::string comp, int sign);
 
-std::vector<double> calculate_summary(std::vector<double> &rts, std::vector<double> &errs, unsigned long nTrl);
+std::vector<double> calculate_summary(std::vector<double> &rts, std::vector<double> &errs, std::vector<double> &slows, unsigned long nTrl);
 
 std::vector<double> calculate_percentile( std::vector<double> vDelta, std::vector<double> rts);
 
@@ -26,7 +26,7 @@ void variable_starting_point(Prms &p, std::vector<double> &sp, int sign);
 
 std::vector<double> calculate_caf(std::vector<double> &rts, std::vector<double> &errs, int nBins);
 
-std::vector<double> linspace(int start, int end, int n);
+// std::vector<double> linspace(int start, int end, int n);
 
 void run_simulation(Prms &p, 
                     std::vector<double> &activation_sum, 
@@ -36,6 +36,7 @@ void run_simulation(Prms &p,
                     std::vector<double> &dr, 
                     std::vector<double> &rts, 
                     std::vector<double> &errs, 
+                    std::vector<double> &slows, 
                     int sign);
 
 void run_simulation(Prms &p, 
@@ -44,6 +45,7 @@ void run_simulation(Prms &p,
                     std::vector<double> &dr, 
                     std::vector<double> &rts, 
                     std::vector<double> &errs, 
+                    std::vector<double> &slows, 
                     int sign);
 
 #endif //CPP_RUNDMCSIM_HPP
